@@ -385,7 +385,7 @@ def display_user_info(user_info: PcsUser):
 
 
 def display_user_infos(
-    *user_infos: Tuple[PcsUser, str], recent_user_id: Optional[int] = None
+    *user_infos: Tuple[PcsUser, str, str], recent_user_id: Optional[int] = None
 ):
     """
     Args:
@@ -393,18 +393,18 @@ def display_user_infos(
     """
 
     table = Table(box=SIMPLE, show_edge=False, highlight=True)
+    table.add_column("Recent", justify="right")
     table.add_column("Index", justify="left")
-    table.add_column("Recent", justify="left")
+    table.add_column("Account Name", justify="left", overflow="fold")
     table.add_column("User Id", justify="left", overflow="fold")
-    table.add_column("User Name", justify="left", overflow="fold")
     table.add_column("Quota", justify="left")
     table.add_column("SVIP", justify="left", overflow="fold")
     table.add_column("VIP", justify="left", overflow="fold")
     table.add_column("Level", justify="left")
     table.add_column("pwd", justify="left", overflow="fold")
 
-    for idx, (user_info, pwd) in enumerate(user_infos, 1):
-        user_id, user_name, auth, age, sex, quota, products, level = user_info
+    for idx, (user_info, pwd, account_name) in enumerate(user_infos, 1):
+        user_id, _, auth, age, sex, quota, products, level = user_info
 
         is_recent = "[green]✔[/green]" if user_id == recent_user_id else ""
 
@@ -426,10 +426,10 @@ def display_user_infos(
                 continue
 
         table.add_row(
-            str(idx),
             is_recent,
+            str(idx),
+            account_name,
             str(user_id),
-            user_name,
             quota_str,
             svip,
             vip,
